@@ -275,7 +275,7 @@ if __name__ == "__main__":
     # device.start()
     # try:
     #     while True:
-    #         print(color('[Device] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
+    #         print(color('[ModbusTcpDevice] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
     #         device.showinfo()
     #         device.showcommunicationerrors()
     #         device.showcommunicationerrorsrate()
@@ -649,7 +649,7 @@ if __name__ == "__main__":
     device.start()
     try:
         while True:
-            print(color('[Device] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
+            print(color('[ModbusTcpDevice] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
             device.showinfo()
             device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
